"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GLMR = void 0;
const constants_1 = require("../../../constants");
const extrinsic_1 = require("../../../extrinsic");
const config_utils_1 = require("../../config.utils");
const moonbeam_common_1 = require("../moonbeam.common");
const asset = moonbeam_common_1.assets[constants_1.AssetSymbol.GLMR];
const acala = moonbeam_common_1.chains[constants_1.ChainKey.Acala];
const parallel = moonbeam_common_1.chains[constants_1.ChainKey.Parallel];
const phala = moonbeam_common_1.chains[constants_1.ChainKey.Phala];
const acalaGlmrId = (0, config_utils_1.getMoonAssetId)(acala);
const parallelGlmrId = (0, config_utils_1.getMoonAssetId)(parallel);
const phalaGlmrId = (0, config_utils_1.getMoonAssetId)(phala);
exports.GLMR = {
    asset,
    origin: moonbeam_common_1.moonbeam,
    deposit: {
        [acala.key]: {
            origin: acala,
            balance: moonbeam_common_1.balance.tokens(acalaGlmrId),
            sourceFeeBalance: moonbeam_common_1.balance.system(),
            extrinsic: moonbeam_common_1.extrinsic
                .xTokens()
                .transfer()
                .successEvent(extrinsic_1.XTokensExtrinsicSuccessEvent.TransferredMultiAssets)
                .origin(acala)
                .asset({
                ForeignAsset: acalaGlmrId,
            }),
        },
        [parallel.key]: {
            origin: parallel,
            balance: moonbeam_common_1.balance.assets(parallelGlmrId),
            sourceFeeBalance: moonbeam_common_1.balance.system(),
            extrinsic: moonbeam_common_1.extrinsic
                .xTokens()
                .transfer()
                .successEvent(extrinsic_1.XTokensExtrinsicSuccessEvent.TransferredMultiAssets)
                .origin(parallel)
                .asset(parallelGlmrId),
        },
        [phala.key]: {
            origin: phala,
            balance: moonbeam_common_1.balance.assets(phalaGlmrId),
            sourceFeeBalance: moonbeam_common_1.balance.system(),
            extrinsic: moonbeam_common_1.extrinsic
                .xTransfer()
                .transfer()
                .successEvent(extrinsic_1.XTransferExtrinsicSuccessEvent.Withdrawn)
                .origin(phala)
                .X2(10),
        },
    },
    withdraw: {
        [acala.key]: moonbeam_common_1.withdraw.xTokens({
            balance: moonbeam_common_1.balance.tokens(acalaGlmrId),
            destination: acala,
            feePerWeight: 8000000,
        }),
        [parallel.key]: moonbeam_common_1.withdraw.xTokens({
            balance: moonbeam_common_1.balance.assets(parallelGlmrId),
            destination: parallel,
            feePerWeight: 8,
        }),
        [phala.key]: moonbeam_common_1.withdraw.xTokens({
            balance: moonbeam_common_1.balance.assets(phalaGlmrId),
            destination: phala,
            feePerWeight: 50000,
        }),
    },
};
//# sourceMappingURL=glmr.js.map