"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.moonriver = exports.moonbeam = exports.moonbase = exports.createConfig = void 0;
const constants_1 = require("../constants");
const moonbase_1 = require("./moonbase");
const moonbeam_1 = require("./moonbeam");
const moonriver_1 = require("./moonriver");
function createConfig(assets, moonAsset, moonChain, chains, configs) {
    return {
        assets,
        moonAsset,
        moonChain,
        deposit: (symbol) => {
            const config = configs[symbol];
            if (!config) {
                throw new Error(`No config found for asset: ${symbol}`);
            }
            return {
                chains: Object.keys(config.deposit).map((chain) => chains[chain]),
                from: (chain) => {
                    const depositConfig = config.deposit[chain];
                    if (!depositConfig) {
                        throw new Error(`No deposit config found for asset: ${symbol} and chain: ${chain}`);
                    }
                    return {
                        asset: config.asset,
                        origin: config.origin,
                        config: depositConfig,
                    };
                },
            };
        },
        withdraw: (symbol) => {
            const config = configs[symbol];
            if (!config) {
                throw new Error(`No config found for asset: ${symbol}`);
            }
            return {
                chains: Object.keys(config.withdraw).map((chain) => chains[chain]),
                to: (chain) => {
                    const withdrawConfig = config.withdraw[chain];
                    if (!withdrawConfig) {
                        throw new Error(`No withdraw config found for asset: ${symbol} and chain: ${chain}`);
                    }
                    return {
                        asset: config.asset,
                        origin: config.origin,
                        config: withdrawConfig,
                    };
                },
            };
        },
    };
}
exports.createConfig = createConfig;
exports.moonbase = createConfig(moonbase_1.MOONBASE_ASSETS_CONFIGS, moonbase_1.MOONBASE_ASSETS_CONFIGS[constants_1.AssetSymbol.DEV], constants_1.MOON_CHAINS[constants_1.MoonChainKey.MoonbaseAlpha], moonbase_1.MOONBASE_CHAINS_CONFIGS, moonbase_1.MOONBASE_CONFIGS);
exports.moonbeam = createConfig(moonbeam_1.MOONBEAM_ASSETS_CONFIGS, moonbeam_1.MOONBEAM_ASSETS_CONFIGS[constants_1.AssetSymbol.GLMR], constants_1.MOON_CHAINS[constants_1.MoonChainKey.Moonbeam], moonbeam_1.MOONBEAM_CHAINS_CONFIGS, moonbeam_1.MOONBEAM_CONFIGS);
exports.moonriver = createConfig(moonriver_1.MOONRIVER_ASSETS_CONFIGS, moonriver_1.MOONRIVER_ASSETS_CONFIGS[constants_1.AssetSymbol.MOVR], constants_1.MOON_CHAINS[constants_1.MoonChainKey.Moonriver], moonriver_1.MOONRIVER_CHAINS_CONFIGS, moonriver_1.MOONRIVER_CONFIGS);
//# sourceMappingURL=config.js.map