"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.xTokens = void 0;
const extrinsic_constants_1 = require("../extrinsic.constants");
const xTokens_constants_1 = require("./xTokens.constants");
/* eslint-disable @typescript-eslint/no-use-before-define */
function xTokens(chain) {
    return {
        transfer: () => transfer(chain),
        transferMultiAsset: () => transferMultiAsset(chain),
        transferMultiCurrencies: () => transferMultiCurrencies(chain),
    };
}
exports.xTokens = xTokens;
function transfer(chain) {
    return {
        successEvent: (event) => ({
            origin: (origin) => ({
                asset: (token) => ({
                    pallet: extrinsic_constants_1.ExtrinsicPallet.XTokens,
                    extrinsic: xTokens_constants_1.XTokensExtrinsic.Transfer,
                    successEvent: event,
                    getParams: (account, amount) => [
                        token,
                        amount,
                        {
                            V1: {
                                parents: 1,
                                interior: {
                                    X2: [
                                        {
                                            Parachain: chain.parachainId,
                                        },
                                        {
                                            AccountKey20: {
                                                network: 'Any',
                                                key: account,
                                            },
                                        },
                                    ],
                                },
                            },
                        },
                        origin.weight,
                    ],
                }),
            }),
        }),
    };
}
function transferMultiAsset(chain) {
    return {
        successEvent: (event) => ({
            origin: (origin) => ({
                asset: (asset) => ({
                    pallet: extrinsic_constants_1.ExtrinsicPallet.XTokens,
                    extrinsic: xTokens_constants_1.XTokensExtrinsic.TransferMultiAsset,
                    successEvent: event,
                    getParams: (account, amount) => [
                        {
                            V1: {
                                id: {
                                    Concrete: {
                                        parents: 1,
                                        interior: {
                                            X2: [
                                                {
                                                    Parachain: origin.parachainId,
                                                },
                                                {
                                                    GeneralKey: asset.originSymbol,
                                                },
                                            ],
                                        },
                                    },
                                },
                                fun: {
                                    Fungible: amount,
                                },
                            },
                        },
                        {
                            V1: {
                                parents: 1,
                                interior: {
                                    X2: [
                                        {
                                            Parachain: chain.parachainId,
                                        },
                                        {
                                            AccountKey20: {
                                                network: 'Any',
                                                key: account,
                                            },
                                        },
                                    ],
                                },
                            },
                        },
                        origin.weight,
                    ],
                }),
            }),
        }),
    };
}
function transferMultiCurrencies(chain) {
    return {
        successEvent: (event) => ({
            origin: (origin) => ({
                assets: (asset, feeAsset) => ({
                    pallet: extrinsic_constants_1.ExtrinsicPallet.XTokens,
                    extrinsic: xTokens_constants_1.XTokensExtrinsic.TransferMultiCurrencies,
                    successEvent: event,
                    getParams: (account, amount, fee = 0n) => [
                        [
                            [
                                {
                                    Token: asset.originSymbol,
                                },
                                amount,
                            ],
                            [
                                {
                                    Token: feeAsset.originSymbol,
                                },
                                fee,
                            ],
                        ],
                        1,
                        {
                            V1: {
                                parents: 1,
                                interior: {
                                    X2: [
                                        {
                                            Parachain: chain.parachainId,
                                        },
                                        {
                                            AccountKey20: {
                                                network: 'Any',
                                                key: account,
                                            },
                                        },
                                    ],
                                },
                            },
                        },
                        origin.weight,
                    ],
                }),
            }),
        }),
    };
}
//# sourceMappingURL=xTokens.js.map